aboutsummaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
authorGravatar Damien Martin-Guillerez <dmarting@google.com>2015-04-20 09:44:08 +0000
committerGravatar Han-Wen Nienhuys <hanwen@google.com>2015-04-20 16:40:41 +0000
commita0a79689260be76002a3058fb461e57a96e26f47 (patch)
tree9aba767e9de81932a9175d757abcc3f9499e02e0
parenta0cb69e0c5b7a66736fd0e6a26c4a871f9396919 (diff)
Bazel compile.sh: prevent BUILD file to be copied in the output
We should also move the output directory to bazel-something so it get excluded from the package path. -- MOS_MIGRATED_REVID=91567602
-rwxr-xr-xcompile.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/compile.sh b/compile.sh
index c4ff9bf394..cf670a797c 100755
--- a/compile.sh
+++ b/compile.sh
@@ -366,8 +366,8 @@ if [ -z "${BAZEL_SKIP_JAVA_COMPILATION}" ]; then
java_compilation "Bazel Java" "$DIRS" "$LIBRARY_JARS" "output"
- # help files: all non java files in src/main/java.
- for i in $(find src/main/java -type f -a \! -name '*.java' | sed 's|src/main/java/||'); do
+ # help files: all non java and BUILD files in src/main/java.
+ for i in $(find src/main/java -type f -a \! -name '*.java' -a \! -name 'BUILD' | sed 's|src/main/java/||'); do
mkdir -p $(dirname output/classes/$i)
cp src/main/java/$i output/classes/$i
done